Map

Struct Map 

pub struct Map<K, V>(/* private fields */);
A map in which the presence of an entry is tied to the lifetime of a RAII handle returned by the insertion.

Implementations

Source

impl<K: Ord, V> Map<K, V>

pub fn new() -> Self

Creates a new, empty map.

pub fn len(&self) -> usize

Gets the number of items in the map.

pub fn is_empty(&self) -> bool

Checks if the map is empty.

pub fn iter(&self) -> Iter<'_, K, V>

Gets an iterator over the contents of the map.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

Gets a mutable iterator over the contents of the map.

pub fn keys(&self) -> Keys<'_, K, V>

Gets an iterator over the keys of the map.

pub fn values(&self) -> Values<'_, K, V>

Gets an iterator over the values of the map.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

Gets a mutable iterator over the values of the map.