insert

Function insert 

pub fn insert<T: Clone + Ord, O: OwnerMut<Set<T>>>(
    owner: O,
    item: T,
) -> Option<SetHandle<T, O>>
Inserts an item into a set, returning a handle to the data if successful. A result of None indicates that either the set could not be accessed or the item already exists.