pub fn insert<K: Clone + Ord, V, O: OwnerMut<Map<K, V>>>(
owner: O,
key: K,
value: V,
) -> Option<MapHandle<K, V, O>>Expand description
Inserts a key-value pair into a map, returning a handle to the data if
successful. A result of None indicates that either the map could not be
accessed or the key already exists.